#
# spec file for package python3-pip
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pip
Version:        7.1.2
Release:        5.3
Url:            http://www.pip-installer.org
Summary:        Pip installs packages. Python packages. An easy_install replacement
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/p/pip/pip-%{version}.tar.gz
Patch0:         pip-6.0.6-shipped-requests-cabundle.patch
BuildRequires:  python3-devel
BuildRequires:  python3-pbr
BuildRequires:  python3-setuptools
# prevent build cycle with python3 requirement
#!BuildIgnore:  python3-pip
# Test requirements (not on SLE12)
%if 0%{?suse_version} != 1315
BuildRequires:  python3-mock
BuildRequires:  python3-pytest
BuildRequires:  python3-scripttest >= 1.3
BuildRequires:  python3-virtualenv >= 1.1.0
%endif
Requires:       python3-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
Pip is a replacement for easy_install. It uses mostly the same techniques for
finding packages, so packages that were made easy_installable should be
pip-installable as well.

%prep
%setup -q -n pip-%{version}
%patch0 -p1

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm %{buildroot}%{_bindir}/pip
ln -s %{_bindir}/pip%{py3_ver} %{buildroot}%{_bindir}/pip
# Remove shipped bundled pem cert file
find %{buildroot} -type f -name "*.pem" | xargs rm -f

%check
%if 0%{?suse_version} != 1315
export PYTHONPATH=%{buildroot}%{python3_sitelib}:$PYTHONPATH
export PYTHONPATH=%{buildroot}%{python3_sitelib}/_vendor/:$PYTHONPATH
python3 setup.py test
%endif

%pre
# Since /usr/bin/pip became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/pip ] || rm -f %{_bindir}/pip

%post
update-alternatives --install %{_bindir}/pip pip %{_bindir}/pip%{py3_ver} 30

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pip %{_bindir}/pip%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS.txt CHANGES.txt LICENSE.txt README.rst
%ghost %{_bindir}/pip
%{_bindir}/pip3
%{_bindir}/pip%{py3_ver}
%{python3_sitelib}/pip-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/pip
%if 0%{?suse_version} >= 1230
%ghost %{_sysconfdir}/alternatives/pip
%endif

%changelog
* Sun Aug 23 2015 arun@gmx.de
- update to version 7.1.2:
  * Don't raise an error if pip is not installed when checking for the
    latest pip version.
* Fri Aug 21 2015 bruno@ioda-net.ch
- update to version 7.1.1 (2015-08-20):
  * Check that the wheel cache directory is writable before we
  attempt to write cached files to them.
  * Move the pip version check until after any installs have been
  performed, thus removing the extraenous warning when
  upgrading pip.
  * Added debug logging when using a cached wheel.
  * Respect platlib by default on platforms that have it separated
  from purlib.
  * Upgrade packaging to 15.3.
    Normalize post-release spellings for rev/r prefixes.
  * Upgrade distlib to 0.2.1.
    Updated launchers to decode shebangs using UTF-8. This allows
  non-ASCII pathnames to be correctly handled.
    Ensured that the executable written to shebangs is normcased.
    Changed ScriptMaker to work better under Jython.
  * Upgrade ipaddress to 1.0.13.
- Packaging:
  * Added python3-pbr dependency to fix build on all plateform
* Sat Jul 18 2015 arun@gmx.de
- update to version 7.1.0:
  * Allow constraining versions globally without having to know
    exactly what will be installed by the pip command. #2731.
  * Accept --no-binary and --only-binary via pip.conf. :issue`2867`.
  * Allow --allow-all-external within a requirements file.
  * Fixed an issue where --user could not be used when --prefix was
    used in a distutils configuration file.
  * Fixed an issue where the SOABI tags were not correctly being
    generated on Python 3.5.
  * Fixed an issue where we were advising windows users to upgrade by
    directly executing pip, when that would always fail on Windows.
  * Allow ~ to be expanded within a cache directory in all situations.
* Mon May 25 2015 arun@gmx.de
- specfile:
  * fixed pythonpath for tests
- update to version 7.0.3:
  * Fixed a regression where --no-cache-dir would raise an exception,
    fixes #2855.
- changes from version 7.0.2:
  * BACKWARD INCOMPATIBLE Revert the change (released in v7.0.0) that
    required quoting in requirements files around specifiers
    containing environment markers. (PR #2841)
  * BACKWARD INCOMPATIBLE Revert the accidental introduction of
    support for options interleaved with requirements, version
    specifiers etc in requirements files. (PR #2841)
  * Expand ~ in the cache directory when caching wheels, fixes #2816.
  * Use python -m pip instead of pip when recommending an upgrade
    command to Windows users.
- changes from version 7.0.1:
  * Don't build and cache wheels for non-editable installations from
    VCSs.
  * Allow --allow-all-external inside of a requirements.txt file,
    fixing a regression in 7.0.
- changes from version 7.0.0:
  * BACKWARD INCOMPATIBLE Removed the deprecated --mirror,
  - -use-mirrors, and -M options.
  * BACKWARD INCOMPATIBLE Removed the deprecated zip and unzip
    commands.
  * BACKWARD INCOMPATIBLE Removed the deprecated --no-install and
  - -no-download options.
  * BACKWARD INCOMPATIBLE No longer implicitly support an insecure
    origin origin, and instead require insecure origins be explicitly
    trusted with the --trusted-host option.
  * BACKWARD INCOMPATIBLE Removed the deprecated link scraping that
    attempted to parse HTML comments for a specially formatted
    comment.
  * BACKWARD INCOMPATIBLE Requirements in requirements files
    containing markers must now be quoted due to parser changes from
    (PR #2697) and (PR #2725). For example, use "SomeProject;
    python_version < '2.7'", not simply SomeProject; python_version <
    '2.7'
  * Ignores bz2 archives if Python wasn't compiled with bz2
    support. Fixes #497
  * Support --install-option and --global-option per requirement in
    requirement files (PR #2537)
  * Build Wheels prior to installing from sdist, caching them in the
    pip cache directory to speed up subsequent installs. (PR #2618)
  * Allow fine grained control over the use of wheels and source
    builds. (PR #2699)
  * --no-use-wheel and --use-wheel are deprecated in favour of new
    options --no-binary and --only-binary. The equivalent of
  - -no-use-wheel is --no-binary=:all:. (PR #2699)
  * The use of --install-option, --global-option or --build-option
    disable the use of wheels, and the autobuilding of wheels. (PR
    [#2711]) Fixes #2677
  * Improve logging when a requirement marker doesn't match your
    environment (PR #2735)
  * Removed the temporary modifications (that began in pip v1.4 when
    distribute and setuptools merged) that allowed distribute to be
    considered a conflict to setuptools. pip install -U setuptools
    will no longer upgrade "distribute" to "setuptools". Instead, use
    pip install -U distribute (PR #2767).
  * Only display a warning to upgrade pip when the newest version is a
    final release and it is not a post release of the version we
    already have installed (PR #2766).
  * Display a warning when attempting to access a repository that uses
    HTTPS when we don't have Python compiled with SSL support (PR
    [#2761]).
  * Allowing using extras when installing from a file path without
    requiring the use of an editable (:pull`2785`).
  * Fix an infinite loop when the cache directory is stored on a file
    system which does not support hard links (PR #2796).
  * Remove the implicit debug log that was written on every
    invocation, instead users will need to use --log if they wish to
    have one (PR #2798).
- changes from version 6.1.1:
  * No longer ignore dependencies which have been added to the
    standard library, instead continue to install them.
- changes from version 6.1.0:
  * Fixes #2502. Upgrades were failing when no potential links were
    found for dependencies other than the current installation. (PR
    [#2538])
  * Use a smoother progress bar when the terminal is capable of
    handling it, otherwise fallback to the original ASCII based
    progress bar.
  * Display much less output when pip install succeeds, because on
    success, users probably don't care about all the nitty gritty
    details of compiling and installing. When pip install fails,
    display the failed install output once instead of twice, because
    once is enough. (PR #2487)
  * Upgrade the bundled copy of requests to 2.6.0, fixing
    CVE-2015-2296.
  * Display format of latest package when using pip list
  - -outdated. (PR #2475)
  * Don't use pywin32 as ctypes should always be available on Windows,
    using pywin32 prevented uninstallation of pywin32 on Windows. (PR
    [#2467])
  * Normalize the --wheel-dir option, expanding out constructs such as
    ~ when used (PR #2441).
  * Display a warning when an undefined extra has been requested. (PR
    [#2142])
  * Speed up installing a directory in certain cases by creating a
    sdist instead of copying the entire directory. (PR #2535)
  * Don't follow symlinks when uninstalling files (PR #2552)
  * Upgrade the bundled copy of cachecontrol from 0.11.1 to
    0.11.2. Fixes #2481 (PR #2595)
  * Attempt to more smartly choose the order of installation to try
    and install dependencies before the projects that depend on
    them. (PR #2616)
  * Skip trying to install libraries which are part of the standard
    library. (PR #2636, PR #2602)
  * Support arch specific wheels that are not tied to a specific
    Python ABI. (PR #2561)
  * Output warnings and errors to stderr instead of stdout. (PR #2543)
  * Adjust the cache dir file checks to only check ownership if the
    effective user is root. (PR #2396)
  * Install headers into a per project name directory instead of all
    of them into the root directory when inside of a virtual
    environment. (PR #2421)
* Thu Feb  5 2015 arun@gmx.de
- update to version 6.0.8:
  * Fix an issue where the --download flag would cause pip to no
    longer use randomized build directories.
  * Fix an issue where pip did not properly unquote quoted URLs which
    contain characters like PEP 440’s epoch separator (!).
  * Fix an issue where distutils installed projects were not actually
    uninstalled and deprecate attempting to uninstall them altogether.
  * Retry deleting directories incase a process like an antivirus is
    holding the directory open temporarily.
  * Fix an issue where pip would hide the cursor on Windows but would
    not reshow it.
* Sat Jan 31 2015 arun@gmx.de
- update to version 6.0.7:
  * Fix a regression where Numpy requires a build path without
    symlinks to properly build.
  * Fix a broken log message when running pip wheel without a
    requirement.
  * Don’t mask network errors while downloading the file as a hash
    failure.
  * Properly create the state file for the pip version check so it
    only happens once a week.
  * Fix an issue where switching between Python 3 and Python 2 would
    evict cached items.
  * Fix a regression where pip would be unable to successfully
    uninstall a project without a normalized version.
* Thu Jan  8 2015 arun@gmx.de
- specfile: update copyright year
- Adapt pip-shipped-requests-cabundle.patch to upstream changes
  >  pip-6.0.6-shipped-requests-cabundle.patch
- Do not ship bundled cacert
- update to version 6.0.6:
  * Continue the regression fix from 6.0.5 which was not a complete
    fix.
- changes from version 6.0.5:
  * Fix a regression with 6.0.4 under Windows where most commands
    would raise an exception due to Windows not having the
    os.geteuid() function.
- changes from version 6.0.4:
  * Fix an issue where ANSI escape codes would be used on Windows even
    though the Windows shell does not support them, causing odd
    characters to appear with the progress bar.
  * Fix an issue where using -v would cause an exception saying
    TypeError: not all arguments converted during string formatting.
  * Fix an issue where using -v with dependency links would cause an
    exception saying TypeError: 'InstallationCandidate' object is not
    iterable.
  * Fix an issue where upgrading distribute would cause an exception
    saying TypeError: expected string or buffer.
  * Show a warning and disable the use of the cache directory when the
    cache directory is not owned by the current use, commonly caused
    by using sudo without the -H flag.
  * Update PEP 440 support to handle the latest changes to PEP 440,
    particularly the changes to >V and <V so that they no longer imply
    !=V.*.
  * Document the default cache directories for each operating system.
  * Create the cache directory when the pip version check needs to
    save to it instead of silently logging an error.
  * Fix a regression where the -q flag would not properly suppress the
    display of the progress bars.
- changes from version 6.0.3:
  * Fix an issue where the implicit version check new in pip 6.0 could
    cause pip to block for up to 75 seconds if PyPI was not
    accessible.
  * Make --no-index imply --disable-pip-version-check.
- changes from version 6.0.2:
  * Fix an issue where the output saying that a package was installed
    would report the old version instead of the new version during an
    upgrade.
  * Fix left over merge conflict markers in the documentation.
  * Document the backwards incompatible PEP 440 change in the 6.0.0
    changelog.
- changes from version 6.0.1:
  * Fix executable file permissions for Wheel files when using the
    distutils scripts option.
  * Fix a confusing error message when an exceptions was raised at
    certain points in pip’s execution.
  * Fix the missing list of versions when a version cannot be found
    that matches the specifiers.
  * Add a warning about the possibly problematic use of > when the
    given specifier doesn’t match anything.
  * Fix an issue where installing from a directory would not copy over
    certain directories which were being excluded, however some build
    systems rely on them.
- changes from version 6.0:
  * PROCESS Version numbers are now simply X.Y where the leading 1 has
    been dropped.
  * BACKWARD INCOMPATIBLE Dropped support for Python 3.1.
  * BACKWARD INCOMPATIBLE Removed the bundle support which was
    deprecated in 1.4. (PR #1806)
  * BACKWARD INCOMPATIBLE File lists generated by pip show -f are now
    rooted at the location reported by show, rather than one
    (unstated) directory lower. (PR #1933)
  * BACKWARD INCOMPATIBLE The ability to install files over the FTP
    protocol was accidently lost in pip 1.5 and it has now been
    decided to not restore that ability.
  * BACKWARD INCOMPATIBLE PEP 440 is now fully implemented, this means
    that in some cases versions will sort differently or version
    specifiers will be interpreted differently than previou sly. The
    common cases should all function similarly to before.
  * DEPRECATION pip install --download-cache and pip wheel
  - -download-cache command line flags have been deprecated and the
    functionality removed. Since pip now automatically configures and
    uses it’s internal HTTP cache which supplants the --download-cache
    the existing options have been made non functional but will still be
    accepted until their removal in pip v8.0. Fo r more information
    please see
    https://pip.pypa.io/en/latest/reference/pip_install.html#caching
  * DEPRECATION pip install --build and pip install --no-clean are now
    NOT deprecated. This reverses the deprecation that occurred in
    v1.5.3. See #906 for discussion.
  * DEPRECATION Implicitly accessing URLs which point to an origin
    which is not a secure origin, instead requiring an opt-in for each
    host using the new --trusted-host flag (pip install -
  - trusted-host example.com foo).
  * Allow the new --trusted-host flag to also disable TLS verification
    for a particular hostname.
  * Added a --user flag to pip freeze and pip list to check the user
    site directory only.
  * Fixed #1873. Silence byte compile errors when installation
    succeed.
  * Added a virtualenv-specific configuration file. (PR #1364)
  * Added site-wide configuation files. (PR #1978)
  * Added an automatic check to warn if there is an updated version of
    pip available (PR #2049).
  * wsgiref and argparse (for >py26) are now excluded from pip list
    and pip freeze (PR #1606, PR #1369)
  * Fixed #1424. Add --client-cert option for SSL client certificates.
  * Fixed #1484. pip show –files was broken for wheel installs. (PR
    [#1635])
  * Fixed #1641. install_lib should take precedence when reading
    distutils config. (PR #1642)
  * Send Accept-Encoding: identity when downloading files in an
    attempt to convince some servers who double compress the
    downloaded file to stop doing so. (PR #1688)
  * Fixed #1559. Stop breaking when given pip commands in uppercase
    (PR #1725)
  * Fixed #1618. Pip no longer adds duplicate logging consumers, so it
    won’t create duplicate output when being called multiple
    times. (PR #1723)
  * Fixed #1769. pip wheel now returns an error code if any wheels
    fail to build.
  * Fixed #1775. pip wheel wasn’t building wheels for dependencies of
    editable requirements.
  * Allow the use of --no-use-wheel within a requirements file. (PR
    [#1859])
  * Fixed #1680. Attempt to locate system TLS certificates to use
    instead of the included CA Bundle if possible. (PR #1866)
  * Fixed #1319. Allow use of Zip64 extension in Wheels and other zip
    files. (PR #1868)
  * Fixed #1101. Properly handle an index or –find-links target which
    has a <base> without a href attribute. (PR #1869)
  * Fixed #1885. Properly handle extras when a project is installed
    via Wheel. (PR #1896)
  * Fixed #1180. Added support to respect proxies in pip search. It
    also fixes #932 and #1104. (PR #1902)
  * Fixed #798 and #1060. pip install –download works with vcs
    links. (PR #1926)
  * Fixed #1456. Disabled warning about insecure index host when using
    localhost. Based off of Guy Rozendorn’s work in PR #1718. (PR
    [#1967])
  * Allow the use of OS standard user configuration files instead of
    ones simply based around $HOME. (PR #2021)
  * Fixed #1825. When installing directly from wheel paths or urls,
    previous versions were not uninstalled. This also fixes #804
    specifically for the case of wheel archives. (PR #1838)
  * Fixed #2075, detect the location of the .egg-info directory by
    looking for any file located inside of it instead of relying on
    the record file listing a directory. (PR #2076)
  * Fixed #1964, #1935, #676, Use a randomized and secure default
    build directory when possible. (PR #2122, CVE-2014-8991)
  * Fixed #1433. Support environment markers in requirements.txt
    files. (pull:2134)
  * Automatically retry failed HTTP requests by default. (PR #1444,
    pull:2147)
  * Fixed #1100 - Handle HTML Encoding better using a method that is
    more similar to how browsers handle it. (PR #1874)
  * Reduce the verbosity of the pip command by default. (PR #2175, PR
    [#2177], PR #2178)
  * Fixed #2031 - Respect sys.executable on OSX when installing from
    Wheels.
  * Display the entire URL of the file that is being downloaded when
    downloading from a non PyPI repository (PR #2183).
  * Support setuptools style environment markers in a source
    distribution (PR #2153).
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Jul  3 2014 speilicke@suse.com
- Update to version 1.5.6:
  * Upgrade requests to 2.3.0 to fix an issue with proxies on Python 3.4.1 (PR #1821).
- Changes from version 1.5.5:
  * Fixes #1632.  Uninstall issues on debianized pypy, specifically issues with
    setuptools upgrades. (PR #1743)
  * Update documentation to point at https://bootstrap.pypa.io/get-pip.py for
    bootstrapping pip.
  * Update docs to point to https://pip.pypa.io/
  * Upgrade the bundled projects (distlib==0.1.8, html5lib==1.0b3, six==1.6.1,
    colorama==0.3.1, setuptools==3.4.4).
- Changes from version 1.5.4:
  * Correct deprecation warning for ``pip install --build`` to only notify when
    the `--build` value is different than the default.
- Changes from version 1.5.3:
  * **DEPRECATION** ``pip install --build`` and ``pip install --no-clean`` are now
    deprecated.  See Issue #906 for discussion.
  * Fixed #1112. Couldn't download directly from wheel paths/urls, and when wheel
    downloads did occur using requirement specifiers, dependencies weren't
    downloaded (PR #1527)
  * Fixed #1320. ``pip wheel`` was not downloading wheels that already existed (PR #1524)
  * Fixed #1111. ``pip install --download`` was failing using local ``--find-links`` (PR #1524)
  * Workaround for Python bug http://bugs.python.org/issue20053 (PR #1544)
  * Don't pass a unicode __file__ to setup.py on Python 2.x (PR #1583)
  * Verify that the Wheel version is compatible with this pip (PR #1569)
- Changes from version 1.5.2:
  * Upgraded the vendored ``pkg_resources`` and ``_markerlib`` to setuptools 2.1.
  * Fixed an error that prevented accessing PyPI when pyopenssl, ndg-httpsclient,
    and pyasn1 are installed
  * Fixed an issue that caused trailing comments to be incorrectly included as
    part of the URL in a requirements file
- Changes from version 1.5.1:
  * pip now only requires setuptools (any setuptools, not a certain version) when
    installing distributions from src (i.e. not from wheel). (Pull #1434).
  * `get-pip.py` now installs setuptools, when it's not already installed (Pull #1475)
  * Don't decode downloaded files that have a ``Content-Encoding`` header. (Pull #1435)
  * Fix to correctly parse wheel filenames with single digit versions. (Pull #1445)
  * If `--allow-unverified` is used assume it also means `--allow-external`. (Pull #1457)
- Add pip-shipped-requests-cabundle.patch: Use system CA bundle
- Don't invoke "2to3" anymore, code works without
* Fri Feb 14 2014 jmatejek@suse.com
- disable test dependencies for SLE 12
- break build cycle when python 3.4 starts requiring python3-pip
* Wed Jan  8 2014 speilicke@suse.com
- Update to version 1.5:
  * **BACKWARD INCOMPATIBLE** pip no longer supports the --use-mirrors,
  - M, and --mirrors flags. The mirroring support has been removed. In
    order to use a mirror specify it as the primary index with -i or
  - -index-url, or as an additional index with --extra-index-url. (Pull #1098, CVE-2013-5123)
  * **BACKWARD INCOMPATIBLE** pip no longer will scrape insecure external urls by
    default nor will it install externally hosted files by default. Users may opt
    into installing externally hosted or insecure files or urls using
  - -allow-external PROJECT and --allow-unverified PROJECT. (Pull #1055)
  * **BACKWARD INCOMPATIBLE** pip no longer respects dependency links by default.
    Users may opt into respecting them again using --process-dependency-links.
  * **DEPRECATION** pip install --no-install and pip install
  - -no-download are now formally deprecated.  See Issue #906 for discussion on
    possible alternatives, or lack thereof, in future releases.
  * **DEPRECATION** pip zip and pip unzip are now formally deprecated.
  * pip will now install Mac OSX platform wheels from PyPI. (Pull #1278)
  * pip now generates the appropriate platform-specific console scripts when
    installing wheels. (Pull #1251)
  * Pip now confirms a wheel is supported when installing directly from a path or
    url. (Pull #1315)
  * Fixed #1097, --ignore-installed now behaves again as designed, after it was
    unintentionally broke in v0.8.3 when fixing Issue #14 (Pull #1352).
  * Fixed a bug where global scripts were being removed when uninstalling --user
    installed packages (Pull #1353).
  * Fixed #1163, --user wasn't being respected when installing scripts from wheels (Pull #1176).
  * Fixed #1150, we now assume '_' means '-' in versions from wheel filenames (Pull #1158).
  * Fixed #219, error when using --log with a failed install (Pull #1205).
  * Fixed #1131, logging was buffered and choppy in Python 3.
  * Fixed #70,  --timeout was being ignored (Pull #1202).
  * Fixed #772, error when setting PIP_EXISTS_ACTION (Pull #1201).
  * Added colors to the logging output in order to draw attention to important
    warnings and errors. (Pull #1109)
  * Added warnings when using an insecure index, find-link, or dependency link. (Pull #1121)
  * Added support for installing packages from a subdirectory using the subdirectory
    editable option. ( Pull #1082 )
  * Fixed #1192. "TypeError: bad operand type for unary" in some cases when
    installing wheels using --find-links (Pull #1218).
  * Fixed #1133 and #317. Archive contents are now written based on system
    defaults and umask (i.e. permissions are not preserved), except that regular
    files with any execute permissions have the equivalent of "chmod +x" applied
    after being written (Pull #1146).
  * PreviousBuildDirError now returns a non-zero exit code and prevents the
    previous build dir from being cleaned in all cases (Pull #1162).
  * Renamed --allow-insecure to --allow-unverified, however the old name will
    continue to work for a period of time (Pull #1257).
  * Fixed #1006, error when installing local projects with symlinks in
    Python 3. (Pull #1311)
  * The previously hidden --log-file otion, is now shown as a general option.
    (Pull #1316)
- Rename binary from pip-3.x to pip3.x to match upstream naming
- Run testsuite
- Removed patches (merged upstream)
  + pip-bug850341.patch
* Tue Nov 26 2013 speilicke@suse.com
- Redownload upstream tarball which was somehow modified locally
* Fri Nov 22 2013 speilicke@suse.com
- Fix alternative link in buildroot
* Fri Nov 22 2013 highwaystar.ru@gmail.com
- update to 1.4.1
  * **New Signing Key** Release 1.4.1 is using a different key than normal with
  fingerprint: 7C6B 7C5D 5E2B 6356 A926 F04F 6E3C BCE9 3372 DCFA
  * Fixed issues with installing from pybundle files (Pull #1116).
  * Fixed error when sysconfig module throws an exception (Pull #1095).
  * Don't ignore already installed pre-releases (Pull #1076).
  * Fixes related to upgrading setuptools (Pull #1092).
  * Fixes so that --download works with wheel archives (Pull #1113).
  * Fixes related to recognizing and cleaning global build dirs (Pull #1080).
- Added pip-bug850341.patch (bcn#850341):
  * fixed pip for python3
* Thu Aug 15 2013 speilicke@suse.com
- Only buildrequire python3-2to3 on 12.2
* Mon Jul 29 2013 speilicke@suse.com
- Run 2to3
* Mon Jul 29 2013 speilicke@suse.com
- Update to version 1.4:
  * **BACKWARD INCOMPATIBLE** pip now only installs stable versions by default,
    and offers a new --pre option to also find pre-release and development
    versions. (Pull #834)
  * **BACKWARD INCOMPATIBLE** Dropped support for Python 2.5. The minimum
    supported Python version for pip 1.4 is Python 2.6.
  * Added support for installing and building wheel archives.
    Thanks Daniel Holth, Marcus Smith, Paul Moore, and Michele Lacchia
    (Pull #845)
  * Applied security patch to pip's ssl support related to certificate DNS
    wildcard matching (http://bugs.python.org/issue17980).
  * To satisfy pip's setuptools requirement, pip now recommends setuptools>=0.8,
    not distribute. setuptools and distribute are now merged into one project
    called 'setuptools'. (Pull #1003)
  * pip will now warn when installing a file that is either hosted externally to
    the index or cannot be verified with a hash. In the future pip will default
    to not installing them and will require the flags --allow-external NAME, and
  - -allow-insecure NAME respectively. (Pull #985)
  * If an already-downloaded or cached file has a bad hash, re-download it rather
    than erroring out. (Issue #963).
  * pip bundle and support for installing from pybundle files is now
    considered deprecated and will be removed in pip v1.5.
  * Fixed a number of issues (#413, #709, #634, #602, and #939) related to
    cleaning up and not reusing build directories. (Pull #865, #948)
  * Added a User Agent so that pip is identifiable in logs. (Pull #901)
  * Added ssl and --user support to get-pip.py. Thanks Gabriel de Perthuis.
    (Pull #895)
  * Fixed the proxy support, which was broken in pip 1.3.x (Pull #840)
  * Fixed issue #32 - pip fails when server does not send content-type header.
    Thanks Hugo Lopes Tavares and Kelsey Hightower (Pull #872).
  * "Vendorized" distlib as pip.vendor.distlib (https://distlib.readthedocs.org/).
  * Fixed git VCS backend with git 1.8.3. (Pull #967)
- Require setuptools instead of distribute again (merged upstream)
- Use update-alternatives for parallel-installability with Python3
* Mon Apr 22 2013 toddrme2178@gmail.com
- Re-add buildrequires: python3.  This is needed for openSUSE <= 12.2
* Mon Apr 22 2013 speilicke@suse.com
- Simpler spec file
* Fri Mar  8 2013 alexandre@exatati.com.br
- Update to 1.3.1:
  * Fixed a major backward incompatible change of parsing URLs to
    externally hosted packages that got accidentily included in 1.3.
- Aditional changes from 1.3:
  * SSL Cert Verification; Make https the default for PyPI access.
    Thanks James Cleveland, Giovanni Bajo, Marcus Smith and many
    others (Pull #789).
  * Added "pip list" for listing installed packages and the latest
    version available. Thanks Rafael Caricio, Miguel Araujo, Dmitry
    Gladkov (Pull #752)
  * Fixed security issues with pip's use of temp build directories.
    Thanks David (d1b) and Thomas Guttler. (Pull #780)
  * Improvements to sphinx docs and cli help. (Pull #773)
  * Fixed issue #707, dealing with OS X temp dir handling, which was
    causing global NumPy installs to fail. (Pull #768)
  * Split help output into general vs command-specific option groups.
    Thanks Georgi Valkov. (Pull #744; Pull #721 contains preceding
    refactor)
  * Fixed dependency resolution when installing from archives with
    uppercase project names. (Pull #724)
  * Fixed problem where re-installs always occurred when using
    file:// find-links. (Pulls #683/#702)
  * "pip install -v" now shows the full download url, not just the
    archive name. Thanks Marc Abramowitz (Pull #687)
  * Fix to prevent unnecessary PyPI redirects. Thanks Alex
    Gronholm (Pull #695)
  * Fixed issue #670 - install failure under Python 3 when the same
    version of a package is found under 2 different URLs. Thanks
    Paul Moore (Pull #671)
  * Fix git submodule recursive updates.  Thanks Roey Berman.
    (Pulls #674)
  * Explicitly ignore rel='download' links while looking for html
    pages. Thanks Maxime R. (Pull #677)
  * --user/--upgrade install options now work together. Thanks
    'eevee' for discovering the problem. (Pull #705)
  * Added check in install --download to prevent re-downloading
    if the target file already exists. Thanks Andrey Bulgakov.
    (Pull #669)
  * Added support for bare paths (including relative paths) as
    argument to --find-links. Thanks Paul Moore for draft patch.
  * Added support for --no-index in requirements files.
  * Added "pip show" command to get information about an installed
    package. Fixes #131. Thanks Kelsey Hightower and Rafael Caricio.
  * Added `--root` option for "pip install" to specify root
    directory. Behaves like the same option in distutils but also
    plays nice with pip's egg-info. Thanks Przemek Wrzos.
    (Issue #253 / Pull #693)
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Sat Sep  8 2012 os-dev@jacraig.com
- Fix Python 3 build.
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Fri Apr 27 2012 toddrme2178@gmail.com
- Add python 3 package
